@@ -1,8 +1,12 @@
+import sys
+from typing import TYPE_CHECKING
 from . import _core
 from ._abc import SendStream, ReceiveStream
 from ._util import ConflictDetector, Final
 from ._core._windows_cffi import _handle, raise_winerror, kernel32, ffi
 
+assert sys.platform == "win32" or not TYPE_CHECKING
+
 # XX TODO: don't just make this up based on nothing.
 DEFAULT_RECEIVE_SIZE = 65536
 
